@@ -5,8 +5,10 @@ import sys
 from pathlib import Path
 from subprocess import run
 
-from ..gui import prompt_filesystem_access, select_steam_app_with_gui
-from ..steam import find_steam_path, get_steam_apps, get_steam_lib_paths
+from ..gui import (prompt_filesystem_access, select_steam_app_with_gui,
+                   select_steam_installation)
+from ..steam import (find_steam_installations, find_steam_path, get_steam_apps,
+                     get_steam_lib_paths)
 from .main import main as cli_main
 from .util import (CustomArgumentParser, cli_error_handler, enable_logging,
                    exit_with_error)
@@ -103,16 +105,17 @@ def main(args=None):
 
     enable_logging(args.verbose, record_to_file=args.no_term)
 
-    try:
-        executable_path = Path(args.executable).resolve(strict=True)
-    except TypeError:  # Python 3.5
-        executable_path = Path(args.executable).resolve()
+    executable_path = Path(args.executable).resolve(strict=True)
 
     # 1. Find Steam path
-    steam_path, steam_root = find_steam_path()
-    if not steam_path:
+    steam_installations = find_steam_installations()
+    if not steam_installations:
         exit_("Steam installation directory could not be found.")
 
+    steam_path, steam_root = select_steam_installation(steam_installations)
+    if not steam_path:
+        exit_("No Steam installation was selected.")
+
     # 2. Find any Steam library folders
     steam_lib_paths = get_steam_lib_paths(steam_path)
 
@@ -140,7 +143,7 @@ def main(args=None):
     if not args.appid:
         appid = select_steam_app_with_gui(
             steam_apps,
-            title="Choose Wine prefix to run {}".format(executable_path.name),
+            title=f"Choose Wine prefix to run {executable_path.name}",
             steam_path=steam_path
         ).appid
     else:
@@ -170,7 +173,7 @@ def main(args=None):
         cli_args += ["--no-term"]
 
     inner_args = " ".join(
-        ["wine", "'{}'".format(str(executable_path))]
+        ["wine", f"'{executable_path}'"]
         + exec_args
     )
 
@@ -182,7 +185,7 @@ def main(args=None):
     logger.info(
         "Calling `protontricks` with the command: %s", cli_args
     )
-    cli_main(cli_args)
+    cli_main(cli_args, steam_path=steam_path, steam_root=steam_root)
 
 
 if __name__ == "__main__":
